@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use GD::Simple;
 
-our $VERSION = "0.20";
+our $VERSION = "0.22";
 
 sub new {
 	my ($class, @args) = @_;
@@ -153,13 +153,13 @@ __END__;
 
 =head1 NAME
 
-Bio::Tools::Alignment::Overview - just another represetation for biolgical sequence alignment
+Bio::Tools::Alignment::Overview - just another represetation for biological sequence alignment.
 
 =head1 DESCRIPTION
 
 This module creates a simple and resumed representation of a biological sequence alignment.
 For now you can ajust the sequence color, with time new customizations will be implemented.
-If you find some problem please let me know.
+If you find any problem please let me know.
 
 =head1 BASIC USAGE
 
@@ -177,6 +177,9 @@ and pass the required parameters.
 	$view->outup('path_to_my_output_file'); # no extension is required.
 	$view->color('color_name'); # 'red'
 
+create the image.
+
+	$view->make_image();
 
 =head1 Methods
 
@@ -184,23 +187,30 @@ For the moment the only customization available is the color for the sequences.
 
 =over
 
-=item $object->input.
+=item INPUT.
 
-	$self->input();
+	$object->input();
 
 The module is compatible with alignments generated by other programs like ClustalW, MUSCLE and T-COFEE.
 
-=item output.
+=item OUTPUT.
 
-	$self->output();
+	$object->output();
 
 No extension is required for the output file, the module generates automatically a .png file. 
 
-=item color.
+=item COLOR.
 
-	$self->color();
+	$object->color();
 
 The module depends on GD::Simple for making the images files so the available colors are listed in L<GD::Simple>.
+The default color is blue.
+
+=item MAKE_IMAGE.
+
+	$object->make_image();
+
+This is the method responsible for generating the image file with png extension.
 
 =back
 
